==> zio-aws-sesv2_3-5.17.129.2-sources.jar: zio/aws/sesv2/model/SuppressionAttributes.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SuppressionAttributes(
    suppressedReasons: Option[
      Iterable[zio.aws.sesv2.model.SuppressionListReason]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.SuppressionAttributes = {
    import SuppressionAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
      .builder()
      .optionallyWith(
        suppressedReasons.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.suppressedReasonsWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.SuppressionAttributes.ReadOnly =
    zio.aws.sesv2.model.SuppressionAttributes.wrap(buildAwsValue())
}
object SuppressionAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.SuppressionAttributes =
      zio.aws.sesv2.model
        .SuppressionAttributes(suppressedReasons.map(value => value))
    def suppressedReasons
        : Option[List[zio.aws.sesv2.model.SuppressionListReason]]
    def getSuppressedReasons
        : ZIO[Any, AwsError, List[zio.aws.sesv2.model.SuppressionListReason]] =
      AwsError.unwrapOptionField("suppressedReasons", suppressedReasons)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ) extends zio.aws.sesv2.model.SuppressionAttributes.ReadOnly {
    override val suppressedReasons
        : Option[List[zio.aws.sesv2.model.SuppressionListReason]] = scala
      .Option(impl.suppressedReasons())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.sesv2.model.SuppressionListReason.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ): zio.aws.sesv2.model.SuppressionAttributes.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sesv2_3-6.20.78.1-sources.jar: zio/aws/sesv2/model/SuppressionAttributes.scala <==
package zio.aws.sesv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SuppressionAttributes(
    suppressedReasons: Optional[
      Iterable[zio.aws.sesv2.model.SuppressionListReason]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.SuppressionAttributes = {
    import SuppressionAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
      .builder()
      .optionallyWith(
        suppressedReasons.map(value =>
          value.map { item =>
            item.unwrap.toString
          }.asJavaCollection
        )
      )(_.suppressedReasonsWithStrings)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.SuppressionAttributes.ReadOnly =
    zio.aws.sesv2.model.SuppressionAttributes.wrap(buildAwsValue())
}
object SuppressionAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.SuppressionAttributes =
      zio.aws.sesv2.model
        .SuppressionAttributes(suppressedReasons.map(value => value))
    def suppressedReasons
        : Optional[List[zio.aws.sesv2.model.SuppressionListReason]]
    def getSuppressedReasons
        : ZIO[Any, AwsError, List[zio.aws.sesv2.model.SuppressionListReason]] =
      AwsError.unwrapOptionField("suppressedReasons", suppressedReasons)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ) extends zio.aws.sesv2.model.SuppressionAttributes.ReadOnly {
    override val suppressedReasons
        : Optional[List[zio.aws.sesv2.model.SuppressionListReason]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.suppressedReasons())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sesv2.model.SuppressionListReason.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.SuppressionAttributes
  ): zio.aws.sesv2.model.SuppressionAttributes.ReadOnly = new Wrapper(impl)
}
